@@ -17,7 +17,7 @@ subtype 'VersionString' =>
 
 subtype 'FrameworkVersionString' =>
   as 'Str' =>
-  where { $_ =~ m{ \A (?: (?:x|[0-9]+x?) \. ){2} (?: x | [0-9]+x? ) \z }xms };
+  where { $_ =~ m{ \A (?: (?:x|[0-9]+x?) \. ){1,2} (?: x | [0-9]+x? ) \z }xms };
 
 subtype 'XMLTree' =>
   as 'Object' =>
@@ -262,13 +262,15 @@ no Moose;
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 OTRS::OPM::Analyzer::Utils::OPMFile - Parser for the .opm file
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
